#
# spec file for package v8
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# check the file DEPS for matching the v8 version with its tools; update
# the _service file accordingly

Name:           v8
Version:        5.3.171
Release:        1.1
Summary:        JavaScript Engine
License:        BSD-3-Clause
Group:          System/Libraries
Url:            http://code.google.com/p/v8

Source0:        %{name}-%{version}.tar.bz2
Source1:        third_party.icu-46.tar.bz2
Source2:        buildtools-00.tar.bz2
Source3:        testing.gmock-00.tar.bz2
Source4:        testing.gtest-00.tar.bz2
Source5:        test.mozilla.data-00.tar.bz2
Source6:        test.simdjs.data-00.tar.bz2
Source7:        test.test262.data-00.tar.bz2
Source8:        tools.swarming_client-00.tar.bz2
Source9:        test.benchmarks.data-00.tar.bz2
Source10:       trace_event-00.tar.bz2
Patch1:         add_ppc64le_arch.patch
# PATCH-FIX-UPSTREAM v8-gcc6.patch mliska@suse.cz -- Fix build with GCC6
Patch2:         v8-gcc6.patch
BuildRequires:  gcc-c++
BuildRequires:  gyp
BuildRequires:  libicu-devel >= 4.0
BuildRequires:  lzma
BuildRequires:  python-devel
BuildRequires:  readline-devel
ExclusiveArch:  %{ix86} x86_64 %arm ppc64 ppc64le
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%global somajor `echo %{version} | cut -f1 -d'.'`
%global sominor `echo %{version} | cut -f2 -d'.'`
%global sobuild `echo %{version} | cut -f3 -d'.'`
%global sover %{somajor}.%{sominor}.%{sobuild}

%description
V8 is Google\'s open source JavaScript engine. V8 is written in C++ and is used
in Google Chrome, the open source browser from Google. V8 implements ECMAScript
as specified in ECMA-262, 3rd edition.

%package -n libv8-5
Summary:        JavaScript Engine
Group:          System/Libraries
Obsoletes:      v8 < %{version}
Provides:       v8 = %{version}

%description -n libv8-5
V8 is Google\'s open source JavaScript engine. This package contains
libraries for v8.

%package devel
Summary:        Development headers and libraries for v8
Group:          Development/Libraries/C and C++
Requires:       lib%{name}-5 = %{version}

%description devel
V8 is Google\'s open source JavaScript engine. This package contains
development headers and libraries for v8.

%if 0%{?suse_version} > 1140 || 0%{?fedora_version}

%package private-headers-devel
Summary:        Private Development headers for v8
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}

%description private-headers-devel
Special Private Development headers for v8.
%endif

%prep
%setup -q -T -b 0

for SRC in %{SOURCE1} %{SOURCE2} %{SOURCE3} %{SOURCE4} %{SOURCE5} \
	    %{SOURCE6} %{SOURCE7} %{SOURCE8} %{SOURCE9}; do
    DIRNAME=$(basename $SRC | rev | cut -d'.' -f3 | rev | cut -d'-' -f 1)
    PATHNAME=$(basename $SRC | rev | cut -d'.' -f4- | tr '.' '/' | rev)

    pushd "$PATHNAME"
    mkdir $DIRNAME
    pushd $DIRNAME
    tar --strip-components=1 -xvf $SRC
    popd
    popd
done
mkdir -p base/trace_event/common
pushd base/trace_event/common
tar --strip-components=1 -xvf %{SOURCE10}
popd
%patch1 -p1
%patch2 -p1

%build

# try to fix the build problems on 32 bit ??????
install -d out/Release/lib

#Link the gypfiles directory to a directory called build as that the other sources are 
#expecting the build directory which contains the gyp files
ln -s gypfiles build

export GYP_DEFINES="component=shared_library soname_version=%{somajor} console=readline clang=0 host_clang=0 use_system_icu=1 linux_use_bundled_binutils=0 linux_use_bundled_gold=0 linux_use_gold_flags=0 v8_enable_backtrace=0"

./gypfiles/gyp_v8 -f make gypfiles/all.gyp --depth .

env=CCFLAGS:"-fPIC"
MAKE_EXTRA_FLAGS=""
%ifarch armv7hl
MAKE_EXTRA_FLAGS+=hardfp=on
%endif

cd out
make %{?_smp_mflags} \
     snapshots=on \
     $MAKE_EXTRA_FLAGS \
     BUILDTYPE=Release V=1

%install
%if 0%{?suse_version} > 1140 || 0%{?fedora_version}
mkdir -p %{buildroot}%{_includedir}/v8/x64
%else
mkdir -p %{buildroot}%{_includedir}
%endif
mkdir -p %{buildroot}%{_libdir}
install -p include/*.h %{buildroot}%{_includedir}

%if 0%{?suse_version} > 1140 || 0%{?fedora_version}
install -p src/*.h %{buildroot}%{_includedir}/v8
install -p src/x64/*.h %{buildroot}%{_includedir}/v8/x64
%endif

install -p out/Release/lib.target/libv8.so* %{buildroot}%{_libdir}/
mkdir -p %{buildroot}%{_bindir}
install -p -m0755 out/Release/d8 %{buildroot}%{_bindir}

cd %{buildroot}%{_libdir}
ln -sf libv8.so.%{somajor} libv8.so

chmod -x %{buildroot}%{_includedir}/v8*.h

%post -n libv8-5 -p /sbin/ldconfig

%postun -n libv8-5 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog LICENSE.* OWNERS
%_bindir/d8

%files -n libv8-5
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog LICENSE.* OWNERS
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/*.h
%{_libdir}/*.so

%if 0%{?suse_version} > 1140 || 0%{?fedora_version}

%files private-headers-devel
%defattr(644,root,root,-)
%{_includedir}/v8/
%endif

%changelog
* Thu Jun 23 2016 tittiatcoke@gmail.com
- Updated the GCC6 patch to prevent possible crashes
* Fri Jun 17 2016 martin.liska@suse.com
- Add memory constraint to 6GB.
* Thu Jun 16 2016 martin.liska@suse.com
- Add v8-gcc6.patch: Fix build with gcc6.
* Tue Jun  7 2016 tittiatcoke@gmail.com
- Update to 5.3.171
  * No changelog available
- Buildsystem:
  * Add source trace_event-00.tar.bz2 to fix the build. This is a
    shared file between chromium and v8, but is part of the
    chromium source.
* Tue Jan 12 2016 normand@linux.vnet.ibm.com
-  increase disk size in _constraints for ppc64le arch
* Tue Dec 15 2015 normand@linux.vnet.ibm.com
-  add _constraints because out of space when building
  on openSUSE:Factory:PowerPC ppc64le
* Thu Nov 19 2015 normand@linux.vnet.ibm.com
- add ppc64 and ppc64le in ExclusiveArch
- new patch to build on ppc64le architecture.
  add_ppc64le_arch.patch
* Fri Nov 13 2015 Rene.vanPaassen@gmail.com
- zoom forward to 4.8.271
  * modified the _service file format, and spec file to
    automatically unpack aux files in right place
* Fri Nov 13 2015 Rene.vanPaassen@gmail.com
- Updated to 4.2.77
- For the update, follow more closely the google build process,
  using the DEPS file to determine the matching support files;
  extract these from the git server with a _service file, and
  unpack them in the right places with the spec file
- updated the spec file to use GYP_DEFINES
* Sun Sep  7 2014 tittiatcoke@gmail.com
- Update to 3.29.43
  - See enclosed Changelog for all changes
* Mon Apr 28 2014 tittiatcoke@gmail.com
- Update to 3.24.25.33
  - Security fixes
  * CVE-2014-1735: Multiple vulnerabilities in V8 fixed in
    version 3.24.35.33
  * CVE-2014-1730: Type confusion in V8
* Thu Mar 20 2014 tittiatcoke@gmail.com
- Update to 3.23.17.23
  - Security fixes (bnc#868707)
  * CVE-2014-1705 Memory corruption in V8
* Thu Dec 19 2013 jengelh@inai.de
- Program binaries must not be within shlib packages
- Set RPM groups
* Fri Dec 13 2013 tittiatcoke@gmail.com
- Update spec-file to fit the changes in V8 (addition of internal
  ICU)
  * Building against system ICU
  * Regenerate Makefiles before using them
* Tue Dec 10 2013 tittiatcoke@gmail.com
- Update to 3.22.24.8
  - Security fixes (bcn#854473):
  * CVE-2013-6638: Buffer overflow in v8
  * CVE-2013-6639: Out of bounds write in v8
  * CVE-2013-6640: Out of bounds read in v8
* Tue Sep 17 2013 tittiatcoke@gmail.com
- Update to 3.21.9
  * Deprecated Persistent functions which were marked to be deprecated.
  * Allowed uncacheable identifiers to go generic (issue 2867).
  * Added scriptId to StackTrace frames (issue 2865).
  * Always visit branches during HGraph building (Chromium issue 280333).
  * Performance and stability improvements on all platforms.
* Tue Jul 16 2013 tittiatcoke@gmail.com
- Update to 3.20.0.1
  * Allowed users of the V8 API to distinguish between unset and
    undefined HiddenValues (issue 2746).
  * Deprecated old style callbacks in the V8 API.
  * Turned on parallel recompilation.
  * Performance and stability improvements on all platforms.
- Add patch fix-gcc48.patch to resolve gcc48 compile issues
  * Adding gcc flags '-Wno-unused-local-typedefs' and
    '-Wno-aggressive-loop-optimizations'
* Thu Apr 18 2013 dimstar@opensuse.org
- Update to version 3.18.0:
  l Enabled pretenuring of fast literals in high promotion mode.
  + Removed preparser library; link preparser executable against
    full V8.
  + Fixed set-up of intrinsic's 'constructor' properties.
  (Chromium issue 229445)
  + ES6 symbols: extended V8 API to support symbols (issue 2158).
  + Removed ARM support for VFP2.
* Sun Apr  7 2013 tittiatcoke@gmail.com
- Update to 3.17.16
  * Stack trace API: poison stack frames below the first strict
    mode frame. (issue 2564)
  * Finished implementation of ES6 symbols aka. private names
    (issue 2158)
  * Disable zapping of global handles in release mode
  * Use internal memcpy when initializing code objects.
  * Turned Flags into a uint32_t typedef
  * Added a version of the v8::HandleScope constructor with an
    v8::Isolate parameter and made
    AdjustAmountOfExternalAllocatedMemory an instance method of
    v8::Isolate.  (issue 2487)
  * Fixed two register allocator bugs (off-by-one error/failure
    propagation). (issue 2576)
  * Fixed heap snapshot creation for Harmony collections.
    (issue 2535)
  * Restored Function()'s expected string representation.
    (issue 2470)
  * Enabled deprecatations (again). (issue 2487)
  * Avoid bool to Oddball conversions by being lazy. (issue 2491)
  * Added %%p option to --logfile.
  * Hardened Function()'s parsing of function literals.
    (issue 2470)
  * ES6 symbols: Refine test for getOwnPropertyNames. (issue 2158)
* Sun Jan 13 2013 idonmez@suse.com
- Enable readline support (console=readline)
* Sun Jan 13 2013 tittiatcoke@gmail.com
- Update to 3.16.4.0
  * Performance and stability improvements on all platforms
  * Improved GC performance when moving parts of a FixedArray
    (issue 2452).
  * Enabled readline on d8 while building a shared lib (issue 1781).
  * Fixed missing exception check in typed array constructor
    (Chromium issue 168545).
  * Check for read-only-ness when preparing for array sort
    (issue 2419).
  * Fixed x64 MathMinMax for negative untagged int32 arguments.
    (Chromium issue 164442)
  * Fixed FloatingPointHelper::CheckSSE2OperandIsInt32.
    (issue 2458)
  * V8_Fatal now prints C++ stack trace in debug mode
  * Added HTML-based tick processor
  * Define CAN_USE_VFP2/3_INSTRUCTIONS based on arm_neon and
    arm_fpu GYP flags
  * Added GCTracer metrics for a scavenger GC for DOM wrappers
  * Activated code aging by default
  * See full list of changes in the ChangeLog
* Wed Dec  5 2012 guillaume@opensuse.org
- Fix armv7 using new flag (hardfp=on)
* Fri Oct 26 2012 tittiatcoke@gmail.com
- Update to 3.14.5.0
  * See changes in ChangeLog
- Remove patch for HARDFLOAT on arm. Now upstream
* Thu Sep 27 2012 guillaume@opensuse.org
- Enable build on ARMv5
* Tue Sep 11 2012 dmueller@suse.com
- set USE_HARDFLOAT on arm
* Wed Aug 22 2012 tittiatcoke@gmail.com
- Update to 3.13.3.0
  * Performance and stability improvements on all platforms.
* Sun Aug 19 2012 tittiatcoke@gmail.com
- Update to 3.13.1.0
  * Added histograms for total allocated/live heap size, as well as
    allocated size and percentage of total for map and cell space.
  * Fixed parseInt's octal parsing behavior
    (ECMA-262 Annex E 15.1.2.2).  (issue 1645)
  * Added checks for interceptors to negative lookup code in
    Crankshaft.  (Chromium issue 140473)
  * Made incremental marking clear ICs and type feedback cells.
* Wed Aug  8 2012 dmueller@suse.com
- fix build on ARM
* Fri Aug  3 2012 tittiatcoke@gmail.com
- Update to 3.12.19.1
  * Forced using bit-pattern for signed zero double. (issue 2239)
  * Made sure double to int conversion is correct. (issue 2260)
  * Always set the callee's context when calling a function from
    optimized code.  (Chromium issue 138887)
  * Fixed building with GCC 3.x (issue 2016, 2017)
  * Improved API calls that return empty handles.  (issue 2245)
* Sun Jul 29 2012 tittiatcoke@gmail.com
- Update to 3.12.16.0
  * Added PRESERVE_ASCII_NULL option to String::WriteAscii.
    (issue 2252)
  * Added dependency to HLoadKeyed* instructions to prevent invalid
    hoisting. (Chromium issue 137768)
  * Enabled building d8 for Android on Mac.
  * Interpret negative hexadecimal literals as NaN.
    (issue 2240)
  * Expose counters in javascript when using --track-gc-object-stats.
  * Enabled building and testing V8 on Android IA.
  * Added --trace-parse flag to parser.
* Wed Jul 25 2012 tittiatcoke@gmail.com
- Update to 3.12.14.0
  * Fixed missing tagging of stack value in finally block.
    (Chromium issue 137496)
  * Added an option to the tickprocessor to specify the directory
    for lib lookup.
  * Fixed ICs for slow objects with native accessor
    (Chromium issue 137002).
  * Fixed transcendental cache on ARM in optimized code
    (issue 2234).
  * New heap inspection tools: counters for object sizes and
    counts, histograms for external fragmentation.
  * Incorporated constness into inferred interfaces (in
    preparation for handling imports) (issue 1569).
* Fri Jul 20 2012 tittiatcoke@gmail.com
- Update to 3.12.11.0
  * Change of buildsystem from scons to GYP
* Sun Jul  8 2012 tittiatcoke@gmail.com
- Update to 3.12.9.0
  * Correctly advance the scanner when scanning unicode regexp
    flag. (Chromium issue 136084)
  * Fixed unhandlified code calling Harmony Proxy traps.
    (issue 2219)
  * Implemented TypedArray.set and ArrayBuffer.slice in d8
  * Fixed lazy compilation for strict eval scopes.
    (Chromium issue 135066)
  * Made MACOSX_DEPLOYMENT_TARGET configurable in GYP.
    (issue 2151)
  * Report "hidden properties" in heap profiler for properties
    case. (issue 2212)
  * Activated optimization of packed arrays by default.
* Mon Jul  2 2012 guillaume@opensuse.org
- ARM: Only enable hardfloat for armv7, since armv5 build is soft only
* Fri Jun 29 2012 tittiatcoke@gmail.com
- Update to 3.12.5.0
  * Fixed Chromium issues:
    115100, 129628, 131994, 132727, 132741, 132742, 133211
  * Fixed V8 issues:
    915, 1914, 2034, 2087, 2094, 2134, 2156, 2166, 2172, 2177,
    2179, 2185
  * Added --extra-code flag to mksnapshot to load JS code into the VM
    before creating the snapshot.
  * Support 'restart call frame' command in the debugger.
  * Fixed lazy sweeping heuristics to prevent old-space expansion.
    (issue 2194)
  * Fixed sharing of literal boilerplates for optimized code.
    (issue 2193)
  * Removed -fomit-frame-pointer flag from Release builds to make
    the stack walkable by TCMalloc (Chromium issue 133723).
  * Expose more detailed memory statistics (issue 2201).
  * Fixed Harmony Maps and WeakMaps for undefined values
  (Chromium issue 132744).
* Tue Jun 19 2012 tittiatcoke@gmail.com
- Update to 3.11.10.6
  * Implemented heap profiler memory usage reporting.
  * Preserved error message during finally block in try..finally.
    (Chromium issue 129171)
  * Fixed EnsureCanContainElements to properly handle double values.
    (issue 2170)
  * Improved heuristics to keep objects in fast mode with inherited
    constructors.
  * Performance and stability improvements on all platforms.
  * Implemented ES5-conformant semantics for inherited setters and
    read-only properties. Currently behind --es5_readonly flag,
    because it breaks WebKit bindings.
  * Exposed last seen heap object id via v8 public api.
* Thu Jun  7 2012 tittiatcoke@gmail.com
- Update to 3.11.8.0
  * Avoid overdeep recursion in regexp where a guarded expression
    with a minimum repetition count is inside another quantifier.
    (Chromium issue 129926)
  * Fixed missing write barrier in store field stub.
    (issues 2143, 1465, Chromium issue 129355)
  * Proxies: Fixed receiver for setters inherited from proxies.
  * Proxies: Fixed ToStringArray function so that it does not
    reject some keys. (issue 1543)
* Wed May 30 2012 tittiatcoke@gmail.com
- Update to 3.11.7.0
  * Get better function names in stack traces.
  * Fixed RegExp.prototype.toString for incompatible receivers
    (issue 1981).
  * Some cleanup to common.gypi. This fixes some host/target
    combinations that weren't working in the Make build on Mac.
  * Handle EINTR in socket functions and continue incomplete sends.
    (issue 2098)
  * Fixed python deprecations.  (issue 1391)
  * Made socket send and receive more robust and return 0 on
    failure.  (Chromium issue 15719)
  * Fixed GCC 4.7 (C++11) compilation.  (issue 2136)
  * Set '-m32' option for host and target platforms
  * Performance and stability improvements on all platforms.
* Sun May 20 2012 tittiatcoke@gmail.com
- Update to 3.11.3.0
  * Disable optimization for functions that have scopes that cannot
    be reconstructed from the context chain. (issue 2071)
  * Define V8_EXPORT to nothing for clients of v8.
    (Chromium issue 90078)
  * Correctly check for native error objects. (Chromium issue 2138)
* Thu May 17 2012 tittiatcoke@gmail.com
- Update to 3.11.2.0
  * Implement map collection for incremental marking. (issue 1465)
  * Added a readbuffer function to d8 that reads a file into an
    ArrayBuffer.
  * Fix freebsd build. (V8 issue 2126)
  * Fixed compose-discard crasher from r11524 (issue 2123).
  * Activated new global semantics by default. Global variables can
    now shadow properties of the global object (ES5.1 erratum).
  * Properly set ElementsKind of empty FAST_DOUBLE_ELEMENTS arrays when
    transitioning (Chromium issue 117409).
  * Made Error.prototype.name writable again, as required by the spec and
    the web (Chromium issue 69187).
  * Implemented map collection with incremental marking (issue 1465).
  * Regexp: Fixed overflow in min-match-length calculation
    (Chromium issue 126412).
  * Fixed crash bug in VisitChoice (Chromium issue 126272).
  * Fixed unsigned-Smi check in MappedArgumentsLookup
    (Chromium issue 126414).
  * Fixed LiveEdit for function with no locals (issue 825).
  * Fixed register clobbering in LoadIC for interceptors
    (Chromium issue 125988).
  * Implemented clearing of CompareICs (issue 2102).
  * Performance and stability improvements on all platforms.
* Wed May  9 2012 tittiatcoke@gmail.com
- Update to 3.10.8.4
  * Enabled MIPS cross-compilation.
  * Ensured reload of elements pointer in StoreFastDoubleElement
    stub. (Chromium issue 125515)
  * Fixed corner cases in truncation behavior when storing to
    TypedArrays. (issue 2110)
  * Fixed failure to properly recognize and report out-of-memory
    conditions when allocating code space pages. (Chromium issue
    118625)
  * Fixed idle notifications to perform a round of incremental GCs
    after context disposal. (issue 2107)
  * Fixed preparser for try statement. (issue 2109)
* Thu Apr 26 2012 tittiatcoke@gmail.com
- Update to 3.10.6.0
  * Fixed some bugs in accessing details of the last regexp match.
  * Fixed source property of empty RegExp objects. (issue 1982)
  * Enabled inlining some V8 API functions.
* Thu Apr 26 2012 joop.boonen@opensuse.org
- spec file fix for arm, ifarch arm isn't correct needs percent sign before arm
* Tue Apr 24 2012 tittiatcoke@gmail.com
- Update to 3.10.5.0
  * Put new global var semantics behind a flag until WebKit tests
    are cleaned up.
  * Enabled stepping into callback passed to builtins.
    (Chromium issue 109564)
  * Fixed issues when stressing compaction with WeakMaps.
  * Fixed missing GVN flag for new-space promotion.
    (Chromium issue 123919)
  * Simplify invocation sequence at monomorphic function
    invocation sites.  (issue 2079)
  * Fixed several bugs in heap profiles (including issue 2078).
  * Throw syntax errors on illegal escape sequences.
  * Implemented rudimentary module linking (behind --harmony flag)
  * Implemented ES5 erratum: Global declarations should shadow
    inherited properties.
  * Made handling of const more consistent when combined with 'eval'
    and 'with'.
  * Fixed V8 on MinGW-x64 (issue 2026).
  * Performance and stability improvements on all platforms.
* Tue Apr 17 2012 tittiatcoke@gmail.com
- Update to 3.10.2.1
  * Fixed native ARM build (issues 1744, 539)
  * Return LOOKUP variable instead of CONTEXT for non-context
    allocated outer scope parameters (Chromium issue 119609).
  * Fixed regular and ElementsKind transitions interfering with
    each other (Chromium issue 122271).
  * Improved performance of keyed loads/stores which have a
    HeapNumber index (issues 1388, 1295).
  * Fixed WeakMap processing for evacuation candidates (issue 2060).
  * Bailout on possible direct eval calls (Chromium issue 122681).
  * Do not assume that names of function expressions are context-allocated
    (issue 2051).
  * Performance and stability improvements on all platforms.
* Wed Apr 11 2012 tittiatcoke@gmail.com
- Update to 3.10.1.0
  * Fixed bug with arguments object in inlined functions (issue
    2045).
  * Fixed performance bug with lazy initialization (Chromium issue
    118686).
  * Added suppport for Mac OS X 64bit builds with GYP.
  * Fixed bug with hidden properties (issue 2034).
  * Fixed a performance bug when reloading pages (Chromium issue
    117767, V8 issue 1902).
  * Fixed bug when optimizing throw in top-level code (issue 2054).
  * Fixed two bugs with array literals (issue 2055, Chromium issue
    121407).
  * Fixed bug with Math.min/Math.max with NaN inputs (issue 2056).
  * Fixed a bug with the new runtime profiler (Chromium issue
    121147).
  * Fixed compilation of V8 using uClibc.
  * Optimized boot-up memory use.
  * Optimized regular expressions.
* Fri Apr  6 2012 tittiatcoke@gmail.com
- Update to 3.10.0.5
  * Fixed store IC writability check in strict mode
    (Chromium issue 120099).
  * Resynchronize timers if the Windows system time was changed.
    (Chromium issue 119815)
  * Removed "-mfloat-abi=hard" from host compiler cflags when
    building for hardfp ARM
  * Fixed edge case for case independent regexp character classes
    (issue 2032).
  * Reset function info counters after context disposal.
    (Chromium issue 117767, V8 issue 1902)
  * Fixed missing write barrier in CopyObjectToObjectElements.
    (Chromium issue 119926)
  * Fixed missing bounds check in HasElementImpl.
    (Chromium issue 119925)
* Sat Mar 24 2012 tittiatcoke@gmail.com
- Update to 3.9.24.1
  * Activated count-based profiler for ARM.
  * Fixed use of proxies as f.prototype properties. (issue 2021)
  * Enabled snapshots on MIPS.
  * Use correct arguments adaptation environment when inlining
    function containing arguments. (Issue 2014)
  * Performance and stability improvements on all platforms
* Wed Mar 21 2012 tittiatcoke@gmail.com
- Update to 3.9.22.0
  * Enabled count-based profiler by default.
  * Implemented a hash based look-up to speed up address checks
    in large object space (issue 853).
  * Fixed push-to-trunk script (and re-push).
  * Added API call that identifies strings that are guaranteed only to
    contain ASCII characters.
  * Fixed declarations escaping global strict eval. (Issue 1624)
  * Fixed wrapping of receiver for non-strict callbacks. (Issue 1973)
  * Fixed function declarations overwriting read-only global properties.
    (Chromium issue 115452)
  * Fixed --use-strict flag in combination with --harmony[-scoping].
  * Debugger: naive implementation of "step into Function.prototype.bind".
  * Debugger: added ability to set script source from within OnBeforeCompile
  * Added flag to always call DebugBreak on abort.
  * Re-enabled constructor inlining and inline === comparison with boolean
    constants. (Issue 2009)
  * Don't use an explicit s0 in ClampDoubleToUint8. (Issue 2004)
  * Performance and stability improvements on all platforms.
* Thu Mar 15 2012 tittiatcoke@gmail.com
- Update to 3.9.19.0
  * Performance and stability improvements on all platforms.
  * Fix the heap profiler crash caused by memory layout changes
    between passes.
  * Fix Error.prototype.toString to throw TypeError. (issue 1980)
  * Fix double-rounding in strtod for MinGW. (issue 1062)
  * Fix corrupted snapshot serializaton on ia32.
    (Chromium issue v8/1985)
  * Added basic interface inference for modules (behind the
  - -harmony flag).
  * Updated the Unicode tables to Unicode version 6.1.0.
  * Fixed VFP detection through compiler defines. (issue 1996)
  * Add Code-related fields to postmortem metadata.
  * Ensure consistency of Math.sqrt on Intel platforms.
  * Remove static initializers in v8. (issue 1859)
  * Add explicit dependency on v8_base in the GYP-based build.
  * Ensure there is a smi check of the receiver for global load and call
    ICs (Chromium issue 117794).
* Sat Mar  3 2012 tittiatcoke@gmail.com
- Update to 3.9.13.0
  * Add code kind check before preparing for OSR. (issue 1900, 115073)
  * Pass zone explicitly to zone-allocation on x64 and ARM. (issue 1802)
  * Port string construct stub to x64. (issue 849)
  * Performance and stability improvements on all platforms.
* Sat Feb 18 2012 tittiatcoke@gmail.com
- Update to 3.9.7.0
  * Fixed V8 issues 1878, 1942, 1945 and Chromium issue 113924.
  * Fixed GCC-4.7 warnings.
  * Added Navier-Stokes benchmark.
  * Performance and stability improvements on all platforms.
* Tue Feb 14 2012 tittiatcoke@gmail.com
- Update to 3.9.6.1
  * Removed unused command line flags
  * Fix template-related linker error. (issue 1936)
  * Allow inlining of functions containing object literals.
    (issue 1322)
  * Add --call-graph-size option to tickprocessor.  (issue 1937)
  * Heap Snapshot maximum size limit is too low for really big
    apps. At the moment the limit is 256MB.
    (Chromium issue 113015)
  * Performance and stability improvements on all platforms.
* Thu Feb  9 2012 tittiatcoke@gmail.com
- Update to 3.9.4.0
  * Properly initialize element-transitioning array literals on ARM.
    (issue 1930)
  * Bug fixes on all platforms.
* Wed Feb  8 2012 tittiatcoke@gmail.com
- Update to 3.9.3.0
  * Optionally export metadata with libv8 to enable debuggers to
    inspect V8 state.
  * Add timestamp to --trace-gc output. (issue 1932)
  * Heap profiler reports implicit references.
  * When rethrowing an exception, print the stack trace of its
    original site instead of rethrow site (Chromium issue 60240).
  * Increased size of small stacks from 32k to 64k to avoid hitting
    limits in Chromium (Chromium issue 112843).
* Mon Feb  6 2012 tittiatcoke@gmail.com
- Update to 3.9.1.0
  * Reduce memory use immediately after starting V8.
  * Fixed memory leak in NativeObjectsExplorer::FindOrAddGroupInfo
    (Chromium issue 112315).
  * Fixed a crash in dev tools (Chromium issue 107996).
  * Added 'dependencies_traverse': 1 to v8 GYP target.
  * Performance and stability improvements on all platforms.
* Sun Jan 29 2012 tittiatcoke@gmail.com
- Update to 3.8.9.0
  * Flush number string cache on GC (issue 1605).
  * Provide access to function inferred name with
    v8::Function::GetInferredName in V8 public API.
  * Fix building with Clang (issue 1912).
  * Reduce the space used by the stack for the profiling thread.
  * Fix misleading documentation of v8::Locker (issue 542).
  * Introduce readbinary function in d8 to read binary files.
  * Performance and stability improvements on all platforms.
* Wed Jan 25 2012 tittiatcoke@gmail.com
- Update to 3.8.8.0
  * Limited number of loop iterations in Heap::ReserveSpace
    (Chromium issue 99027).
  * Fixed solaris build (VirtualMemory) (issue 1761).
  * Fixed strict vs. non-strict handling of function proxies in
    higher-order array and string methods.
  * Enabled asynchronous remote debugging with d8 (issue 1691).
* Mon Jan 23 2012 tittiatcoke@gmail.com
- Update to 3.8.7.1
  * Resolves CVE-2011-5037
  * Ensure that LRandom restores rsi after call to the C function
    on x64.  (Chromium issue http://crbug.com/110509)
  * Fixing include issues on *bsd when building with scons.
    (issue 1897)
  * Provide a switch to specify -fno-strict-aliasing
    (issue 1887)
  * Move WIN32 define from standalone.gypi to common.gypi
    (issue 1760)
  * Fix corner-case in heap size estimation.
    (issue 1893)
  * Fix and enable NEW_NON_STRICT_FAST ArgumentsAccess stub on x64.
    (issue 1903)
  * Performance improvements and bug fixes.
  * Add primitive WebGL array support to d8.
  * Improve heap size estimation (issue 1893).
  * Hash collision DOS workaround extended from string keys
    to numeric keys.
  * Provide an API for iterating through all external strings referenced
    from the JS heap.
  * Adjust position recorded for call expressions. http://crbug.com/109195
  * Fix GC crash related to instanceof. http://crbug.com/109448
  * Fix broken test that assumes that no GC can clear the regexp cache (GC
    can happen at any time due to Crankshaft).
  * Fix handling of bogus receivers for Harmony collections. (issue 1884)
  * Add netbsd support to gyp build.
  * Determine page size at runtime on posix platforms.
  * Ensure that store buffer filtering hash sets are cleared after
    StoreBuffer::Filter.
  * Randomize the seed used for string hashing.  This helps guard against
    CPU-eating DOS attacks against node.js servers.  Based on code from
    Bert Belder.
  * Implement callback when script finishes running in V8 API.
  * Improve performance of Math.min and Math.max for the case of two
    arguments. (issue 1325)
* Mon Jan  9 2012 tittiatcoke@gmail.com
- Update to 3.8.4.1
  * Performance improvements for large Smi-only arrays.
  * Fixed InternalArrays construction. (issue 1878)
* Sat Dec 31 2011 tittiatcoke@gmail.com
- Update to 3.8.3
  * Avoid embedding new space objects into code objects in the
    lithium gap resolver. (chromium:108296)
  * Bug fixes and performance optimizations on all platforms.
* Wed Dec 28 2011 tittiatcoke@gmail.com
- Update to 3.8.2.1
  * Removed exit-time destructors.
  * Set maximum length of FixedArray in terms of elements instead
    an absolute number of bytes.  (Chromium issue 103103)
  * Fixed bug when generating padding to ensure space for lazy
    deoptimization. (issue 1846)
  * Further reduced pause times due to GC.
  * Increase tick interval for the android platform.
  * Fix a bug in the register allocator. (chromium:105112)
  * Fix handling of recompiling code. (chromium:105375, v8:1782)
  * Start incremental marking on idle notification. (v8:1458)
  * Build fixes for various platforms.
  * Fixed handling of arrays in DefineOwnProperty. (issue 1756)
  * Sync parser and preparser on do-while and return statements.
    (issue 1856)
  * Fixed another corner case for DefineOwnProperty on arrays
    (issue 1756).
  * Fixed GCC 4.7 warnings. Patch from Tobias Burnus.
  * Add max optimization flag to v8 gyp build to ensure V8 is
    always built fully optimized in Chrome.
  * MIPS: Bring MIPS to parity with other platforms.
  * Optimizations and stability improvements on all platforms.
* Wed Dec 14 2011 joop.boonen@opensuse.org
- ARM build fix: Changed ExclusiveArch from arm to %%arm
- Added code to build for hardfp
* Fri Dec  9 2011 coolo@suse.com
- fix license to be in spdx.org format
* Tue Dec  6 2011 tittiatcoke@gmail.com
- Update to 3.7.12.6
  * Increase tick interval for the android platform.
  * Fix a bug in the register allocator. (chromium:105112)
  * Fix handling of recompiling code. (chromium:105375, v8:1782)
  * Start incremental marking on idle notification. (v8:1458)
  * Build fixes for various platforms.
  * Various performance improvements.
* Sat Dec  3 2011 tittiatcoke@gmail.com
- Update to 3.7.11
  * Fixed bug when generating padding to ensure space for lazy
    deoptimization. (issue 1846)
  * Further reduced pause times due to GC.
  * Set maximum length of FixedArray in terms of elements
    instead an absolute number of bytes. (Chromium issue 103103)
  * Stability and performance improvements on all platforms.
  * Removed exit-time destructors.
* Sun Nov 20 2011 tittiatcoke@gmail.com
- Update to 3.7.8.0
  * Fix missing fast property accessors in heap snapshots.
    (issue 1818)
  * Removed hidden prototype from builtins, i.e., deleting an
    overridden function on builtins will not make the original
    function reappear.
  * Added NetBSD support for scons build.
  * Performance improvements on all platforms.
* Sat Nov 12 2011 tittiatcoke@gmail.com
- Update to 3.7.6.0
  * Fix Harmony sets and maps to allow null and undefined as keys
    (still hidden behind --harmony flag) (issue 1622).
  * Implement VirtualMemory on FreeBSD to fix build (issue 1807).
  * Enable VFP instructions for Android.
  * Fix error handling in Date.prototype.toISOString (issue 1792).
  * Fixed filtering of store buffer for large object pages.
    (issue 1817)
  * Fixed generated hash function on all platforms.
    (issue 1808)
  * Fixed Heap::Shrink to ensure that it does not free pages that are
    still in use. (Chromium issue 100414)
* Sun Oct 30 2011 tittiatcoke@gmail.com
- Update to 3.7.3.0
  * Slight deoptimization as a workaround for issue with jslint:
    Issue 1789.
  * Fix bug in deoptimization.  Known issue with jslint:
    Issue 1789.
  * Achieved 33%% speedup in debug-mode tests.
  * Removed special casing of calls to RegExp test and exec
    methods with no argument.  Now matches new JSC behaviour.
    crbug.com/75740.
  * Return the empty string on cyclic references in toString
    (ES5 conformance).
  * Fixed bug triggered by JSBeautifier.  crbug.com/100409.
  * Made Math.random state per-context instead of per-process
    issue 864.
  * Fixed stack traces to skip native functions.
  * Make snapshots (new contexts) smaller and faster.
  * Fixed handling of Function.apply for non-array arguments.
  * Fixed evaluation order in defineProperties to match FireFox.
  * Fixed handling of non-object receivers for array builtins,
    crbug.com/100702.
  * Multiple fixes to improve compliance with test262.
  * Fixed compatibility with older Android releases.
  * Fixed compilation with gcc-4.5.3.
  * Improved performance of WriteUtf8, issue 1665.
  * Made native syntax an early error in the preparser.
  * Fixed issues 793 and 893 relating to Function.prototype.bind.
  * Improved let, const, Set and Map support and other Harmony
    features (behind the --harmony flag).
  * Changed evaluation order for > and <= to match ES5 instead
    of ES3.
  * Bug fixes and performance improvements on all platforms.
  * Fixed array handling for Object.defineOwnProperty
    (ES5 conformance).
  * Fixed issue 1757 (string slices of external strings).
  * Fixed issue 1759 (ARM).
  * Added flag --noclever-optimizations to disable some things that
    caused trouble in the past.
  * Added flag --stress-compaction for testing.
  * Added flag --harmony to activate all experimental Harmony features.
* Sun Oct 23 2011 tittiatcoke@gmail.com
- Update to 3.6.6.4
  * Bugfixes
* Sun Oct 16 2011 tittiatcoke@gmail.com
- Change the build process for openSUSE >= 12.1 to enable
  building the Python bindings for V8.
  + Create a separate package for the internal src header-files
    required by PyV8
* Sat Oct  1 2011 tittiatcoke@gmail.com
- Update to 3.6.4.1
  * Bugfixes
* Sat Sep 24 2011 tittiatcoke@gmail.com
- Update to 3.6.4.0
  + Implemented better support of typed arrays in the d8 shell.
  + Bug fixes and performance improvements on all platforms.
  + Fixed d8's broken readline history.
  + Removed the need for code delete events in CPU profiler
    (Issue 1466).
  + Fixed debugger stepping next with trycatch recursion
    (Issue 1639).
  + Fixing parallel execution in d8 (with -p) and some memory
    leaks.
  + Support for precise stepping in functions compiled before
    debugging was started (step 1).
* Mon Sep 12 2011 tittiatcoke@gmail.com
- Update to 3.6.2.0
  + Fixed a bug when optimizing named function expression (issue 1647).
  + Fixed a bug when optimizing f.call.apply (issue 1650).
  + Made arguments and caller always be null on native functions
    (issues 1548 and 1643).
  + Fixed issue 1648 (cross-compiling x64 targeting ia32).
  + Fixed issue 371 (d8 printing of strings containing \0).
  + Fixed order of evaluation in arguments to parseInt (issue 1649).
  + Fixed a problem with large heap snapshots in Chrome DevTools
    (issue 1658, chromium issue 89268).
  + Upped default maximum heap size from 512M to 700M.
  + Fixed a bug in abrupt exit from with or catch inside finally.
  + Fixed possible crash in FixedDoubleArray::Initialize() (Chromium
    issue 95113).
  + Fixed a bug in Page::GetRegionMaskForSpan (Chromium issue 94425).
  + Fixed a few clang warnings (which -Werror treated as errors).
  + Performance improvements on all platforms.
  + Added ability to turn profiler on/off in d8.
  + Fixed several crash bugs.
* Fri Sep  2 2011 tittiatcoke@gmail.com
- Update to 3.5.10.0
  +  Added V8EXPORT attributes for v8::Array::CheckCast and
    v8::Number::CheckCast.
  +  Made a slight API change enabling opting out from null
    termination in String::Write*().
  +  Made FromPropertyDescriptor not trigger inherited setters.
  +  Various bugfixes
* Wed Aug 24 2011 tittiatcoke@gmail.com
- update to 3.5.7.0
  + Make scanner handle invalid unicode escapes in identifiers correctly.
  + Make regexp flag parsing stricter.
  + Fix several memory leaks.
- Cleanup of specfile and changelog to prepare for submission to
  Factory
* Mon Aug 22 2011 tittiatcoke@gmail.com
- Stop building libv8 in debug mode. Chromium doesn't like this
  and starts cpu hogging.
* Fri Aug 19 2011 tittiatcoke@gmail.com
- Update to 3.5.6.0
  + Fixed issue that could cause crashes when running with --heap-stats.
  + Fixed compilation on Linux 2.6.9 and older.
  + Fixed live-object-list to work with isolates.
  + Fixed memory leaks in zones and isolates.
  + Fixed a performance regression for TypedArrays on x64.
  + Stability improvements on all platforms.
* Tue Aug 16 2011 tittiatcoke@gmail.com
- Update to 3.5.5.0
  + Fixed bugs involving negative zero and the optimizing compiler.
  + Fixed optimized version of Function.apply(x, arguments). (issue 1592)
  + Eliminated uses of deprecated ARM instructions.
  + Sped up Math.floor by using SSE 4.1 roundsd instruction on ia32.
  + Removed restriction on the size of disassembled code that is printed.
* Sat Aug  6 2011 tittiatcoke@gmail.com
- Update to 3.5.2.0
* Sat Jul 30 2011 tittiatcoke@gmail.com
- Update to 3.5.1.0
* Thu Jul 21 2011 tittiatcoke@gmail.com
- Update to 3.4.13
* Sun Jul 17 2011 tittiatcoke@gmail.com
- Update to 3.4.12.1
* Mon Jun 20 2011 tittiatcoke@gmail.com
- Update to 3.4.4.0
* Mon Jun 13 2011 tittiatcoke@gmail.com
- Update to 3.4.3.0
* Tue May 31 2011 tittiatcoke@gmail.com
- Update to 3.4.0.1
* Sat May 28 2011 tittiatcoke@gmail.com
- Update to 3.3.10.1
* Wed May 25 2011 tittiatcoke@gmail.com
- Update to 3.3.10.0
* Wed May 25 2011 tittiatcoke@gmail.com
- Update to 3.3.9.3
* Fri May  6 2011 tittiatcoke@gmail.com
- Update to 3.3.4.0
* Thu Apr 28 2011 tittiatcoke@gmail.com
- Update to 3.3.2.0
* Fri Apr 22 2011 tittiatcoke@gmail.com
- Update to 3.3.1.0
* Mon Apr 18 2011 tittiatcoke@gmail.com
- Update to 3.2.10.0
* Tue Apr 12 2011 tittiatcoke@gmail.com
- Update to 3.2.9.1
* Fri Apr  8 2011 tittiatcoke@gmail.com
- Update to 3.2.8.3
* Thu Mar 31 2011 tittiatcoke@gmail.com
- Update to 3.2.6.0
* Mon Mar 28 2011 tittiatcoke@gmail.com
- Update to 3.2.5.0
* Fri Mar 18 2011 tittiatcoke@gmail.com
- Update to 3.2.3.1
* Wed Mar 16 2011 tittiatcoke@gmail.com
- Update to 3.2.2.1
* Fri Mar 11 2011 tittiatcoke@gmail.com
- Update to 3.2.1.1
* Wed Mar  9 2011 tittiatcoke@gmail.com
- Update to 3.2.0.2
* Fri Mar  4 2011 tittiatcoke@gmail.com
- Update to 3.1.8.0
* Wed Mar  2 2011 tittiatcoke@gmail.com
- Update to 3.1.7.0
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 3.1.6.1
* Sun Feb 27 2011 tittiatcoke@gmail.com
- Update to 3.1.6.0
* Wed Feb 16 2011 tittiatcoke@gmail.com
- Update to 3.1.5.0
* Thu Jan 20 2011 tittiatcoke@gmail.com
- Update to 3.0.9.0
* Wed Jan  5 2011 rwooninck@opensuse.org
- Update to 3.0.6.0
* Tue Dec 21 2010 rwooninck@opensuse.org
- update to 3.0.4.1
* Fri Dec 17 2010 tittiatcoke@gmail.com
- Update to 3.0.3.0
* Tue Dec  7 2010 tittiatcoke@gmail.com
- update to 3.0.0.1
* Wed Dec  1 2010 tittiatcoke@gmail.com
- update to 2.5.9.1
* Thu Nov 25 2010 tittiatcoke@gmail.com
- update to 2.5.8.0
  * new package (libv8-2) to follow package specifications.
* Thu Nov 11 2010 tittiatcoke@gmail.com
- update to 2.5.6.0
* Wed Nov  3 2010 tittiatcoke@gmail.com
- update to 2.5.3.0
* Wed Oct 27 2010 tittiatcoke@gmail.com
- Update to 2.5.2.0
* Fri Oct 22 2010 tittiatcoke@gmail.com
- update to 2.5.1.0
* Fri Oct 15 2010 tittiatcoke@gmail.com
- Update to 2.4.9.0
